@@ -1,59 +1,13 @@
+from typing import Any
+
 from .text_decorations import html_decoration, markdown_decoration
 
-LIST_MD_SYMBOLS = "*_`["
 
-MD_SYMBOLS = (
-    (LIST_MD_SYMBOLS[0], LIST_MD_SYMBOLS[0]),
-    (LIST_MD_SYMBOLS[1], LIST_MD_SYMBOLS[1]),
-    (LIST_MD_SYMBOLS[2], LIST_MD_SYMBOLS[2]),
-    (LIST_MD_SYMBOLS[2] * 3 + "\n", "\n" + LIST_MD_SYMBOLS[2] * 3),
-    ("||", "||"),
-    ("<b>", "</b>"),
-    ("<i>", "</i>"),
-    ("<code>", "</code>"),
-    ("<pre>", "</pre>"),
-    ('<span class="tg-spoiler">', "</span>"),
-    ("<tg-spoiler>", "</tg-spoiler>"),
-)
-
-HTML_QUOTES_MAP = {"<": "&lt;", ">": "&gt;", "&": "&amp;", '"': "&quot;"}
-
-_HQS = HTML_QUOTES_MAP.keys()  # HQS for HTML QUOTES SYMBOLS
-
-
-def quote_html(*content, sep=" ") -> str:
-    """
-    Quote HTML symbols
-
-    All <, >, & and " symbols that are not a part of a tag or
-    an HTML entity must be replaced with the corresponding HTML entities
-    (< with &lt; > with &gt; & with &amp and " with &quot).
-
-    :param content:
-    :param sep:
-    :return:
-    """
-    return html_decoration.quote(_join(*content, sep=sep))
-
-
-def escape_md(*content, sep=" ") -> str:
-    """
-    Escape markdown text
-
-    E.g. for usernames
-
-    :param content:
-    :param sep:
-    :return:
-    """
-    return markdown_decoration.quote(_join(*content, sep=sep))
-
-
-def _join(*content, sep=" "):
+def _join(*content: Any, sep: str = " ") -> str:
     return sep.join(map(str, content))
 
 
-def text(*content, sep=" "):
+def text(*content: Any, sep: str = " ") -> str:
     """
     Join all elements with a separator
 
@@ -64,7 +18,7 @@ def text(*content, sep=" "):
     return _join(*content, sep=sep)
 
 
-def bold(*content, sep=" ") -> str:
+def bold(*content: Any, sep: str = " ") -> str:
     """
     Make bold text (Markdown)
 
@@ -72,12 +26,10 @@ def bold(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return markdown_decoration.bold(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
+    return markdown_decoration.bold(value=markdown_decoration.quote(_join(*content, sep=sep)))
 
 
-def hbold(*content, sep=" ") -> str:
+def hbold(*content: Any, sep: str = " ") -> str:
     """
     Make bold text (HTML)
 
@@ -85,12 +37,10 @@ def hbold(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.bold(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.bold(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
-def italic(*content, sep=" ") -> str:
+def italic(*content: Any, sep: str = " ") -> str:
     """
     Make italic text (Markdown)
 
@@ -98,12 +48,10 @@ def italic(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return markdown_decoration.italic(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
+    return markdown_decoration.italic(value=markdown_decoration.quote(_join(*content, sep=sep)))
 
 
-def hitalic(*content, sep=" ") -> str:
+def hitalic(*content: Any, sep: str = " ") -> str:
     """
     Make italic text (HTML)
 
@@ -111,38 +59,10 @@ def hitalic(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.italic(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.italic(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
-def spoiler(*content, sep=" ") -> str:
-    """
-    Make spoiler text (Markdown)
-
-    :param content:
-    :param sep:
-    :return:
-    """
-    return markdown_decoration.spoiler(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
-
-
-def hspoiler(*content, sep=" ") -> str:
-    """
-    Make spoiler text (HTML)
-
-    :param content:
-    :param sep:
-    :return:
-    """
-    return html_decoration.spoiler(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
-
-
-def code(*content, sep=" ") -> str:
+def code(*content: Any, sep: str = " ") -> str:
     """
     Make mono-width text (Markdown)
 
@@ -150,12 +70,10 @@ def code(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return markdown_decoration.code(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
+    return markdown_decoration.code(value=markdown_decoration.quote(_join(*content, sep=sep)))
 
 
-def hcode(*content, sep=" ") -> str:
+def hcode(*content: Any, sep: str = " ") -> str:
     """
     Make mono-width text (HTML)
 
@@ -163,12 +81,10 @@ def hcode(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.code(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.code(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
-def pre(*content, sep="\n") -> str:
+def pre(*content: Any, sep: str = "\n") -> str:
     """
     Make mono-width text block (Markdown)
 
@@ -176,12 +92,10 @@ def pre(*content, sep="\n") -> str:
     :param sep:
     :return:
     """
-    return markdown_decoration.pre(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
+    return markdown_decoration.pre(value=markdown_decoration.quote(_join(*content, sep=sep)))
 
 
-def hpre(*content, sep="\n") -> str:
+def hpre(*content: Any, sep: str = "\n") -> str:
     """
     Make mono-width text block (HTML)
 
@@ -189,12 +103,10 @@ def hpre(*content, sep="\n") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.pre(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.pre(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
-def underline(*content, sep=" ") -> str:
+def underline(*content: Any, sep: str = " ") -> str:
     """
     Make underlined text (Markdown)
 
@@ -202,12 +114,10 @@ def underline(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return markdown_decoration.underline(
-        value=markdown_decoration.quote(_join(*content, sep=sep))
-    )
+    return markdown_decoration.underline(value=markdown_decoration.quote(_join(*content, sep=sep)))
 
 
-def hunderline(*content, sep=" ") -> str:
+def hunderline(*content: Any, sep: str = " ") -> str:
     """
     Make underlined text (HTML)
 
@@ -215,12 +125,10 @@ def hunderline(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.underline(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.underline(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
-def strikethrough(*content, sep=" ") -> str:
+def strikethrough(*content: Any, sep: str = " ") -> str:
     """
     Make strikethrough text (Markdown)
 
@@ -233,7 +141,7 @@ def strikethrough(*content, sep=" ") -> str:
     )
 
 
-def hstrikethrough(*content, sep=" ") -> str:
+def hstrikethrough(*content: Any, sep: str = " ") -> str:
     """
     Make strikethrough text (HTML)
 
@@ -241,9 +149,7 @@ def hstrikethrough(*content, sep=" ") -> str:
     :param sep:
     :return:
     """
-    return html_decoration.strikethrough(
-        value=html_decoration.quote(_join(*content, sep=sep))
-    )
+    return html_decoration.strikethrough(value=html_decoration.quote(_join(*content, sep=sep)))
 
 
 def link(title: str, url: str) -> str:
@@ -268,6 +174,30 @@ def hlink(title: str, url: str) -> str:
     return html_decoration.link(value=html_decoration.quote(title), link=url)
 
 
+def blockquote(*content: Any, sep: str = "\n") -> str:
+    """
+    Make blockquote (Markdown)
+
+    :param content:
+    :param sep:
+    :return:
+    """
+    return markdown_decoration.blockquote(
+        value=markdown_decoration.quote(_join(*content, sep=sep))
+    )
+
+
+def hblockquote(*content: Any, sep: str = "\n") -> str:
+    """
+    Make blockquote (HTML)
+
+    :param content:
+    :param sep:
+    :return:
+    """
+    return html_decoration.blockquote(value=html_decoration.quote(_join(*content, sep=sep)))
+
+
 def hide_link(url: str) -> str:
     """
     Hide URL (HTML only)
@@ -276,4 +206,4 @@ def hide_link(url: str) -> str:
     :param url:
     :return:
     """
-    return f'<a href="{url}">&#8288;</a>'
+    return f'<a href="{url}">&#8203;</a>'
